(function (global, factory) {
	typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/common'), require('@angular/core'), require('@angular/forms'), require('ngx-bootstrap/datepicker'), require('ngx-bootstrap/timepicker')) :
	typeof define === 'function' && define.amd ? define(['exports', '@angular/common', '@angular/core', '@angular/forms', 'ngx-bootstrap/datepicker', 'ngx-bootstrap/timepicker'], factory) :
	(factory((global['ngx-bootstrap-datetime-popup'] = {}),global.common,global.core,global.forms,global.datepicker,global.timepicker));
}(this, (function (exports,common,core,forms,datepicker,timepicker) { 'use strict';

var DatetimePopupButtonOptions = /** @class */ (function () {
    /**
     * @param {?} label
     */
    function DatetimePopupButtonOptions(label) {
        this.show = true;
        this.label = '';
        this.cssClass = 'btn btn-secondary btn-sm';
        this.label = label;
    }
    return DatetimePopupButtonOptions;
}());

var DatetimePopupComponent = /** @class */ (function () {
    function DatetimePopupComponent() {
        this.valueChange = new core.EventEmitter();
        this.showPopup = false;
        this.showPopupChange = new core.EventEmitter();
        this.showDate = true;
        this.showTime = true;
        this.showWeeks = false;
        this.datepickerMode = 'day';
        this.initDate = null;
        this.minDate = null;
        this.maxDate = null;
        this.dateDisabled = [];
        this.localValue = null;
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    DatetimePopupComponent.prototype.ngOnChanges = function (changes) {
        if (!this.nowButton) {
            this.nowButton = new DatetimePopupButtonOptions('Now');
        }
        if (!this.clearButton) {
            this.clearButton = new DatetimePopupButtonOptions('Clear');
        }
        if (!this.closeButton) {
            this.closeButton = new DatetimePopupButtonOptions('Close');
        }
        // user maybe typing a value into an input box, so would come in as string
        if (typeof this.value === 'string') {
            // check if the string is a valid date
            if (!isNaN(new Date(this.value).getTime())) {
                this.localValue = new Date(this.value);
            }
        }
        else if (this.value) {
            this.localValue = this.value;
        }
    };
    /**
     * @return {?}
     */
    DatetimePopupComponent.prototype.offClick = function () {
        this.showPopup = false;
        this.showPopupChange.emit(false);
    };
    /**
     * @return {?}
     */
    DatetimePopupComponent.prototype.onNow = function () {
        this.localValue = new Date();
        this.onPickerChange();
    };
    /**
     * @return {?}
     */
    DatetimePopupComponent.prototype.onClear = function () {
        this.valueChange.emit(null);
    };
    /**
     * @return {?}
     */
    DatetimePopupComponent.prototype.onPickerChange = function () {
        this.valueChange.emit(this.localValue);
        // close when value changed if only using date
        if (this.showDate === true && this.showTime === false) {
            this.offClick();
        }
    };
    DatetimePopupComponent.decorators = [
        { type: core.Component, args: [{
                    selector: 'datetime-popup',
                    template: "\n        <div class=\"dropdown\" [ngClass]=\"{ 'show': showPopup === true }\" (offClick)=\"offClick()\">\n            <ul class=\"dropdown-menu\" role=\"menu\" [ngClass]=\"{ 'show': showPopup === true }\">\n                <li class=\"my-2 mx-2\">\n                    <datepicker *ngIf=\"showDate\" \n                                [(ngModel)]=\"localValue\" \n                                (ngModelChange)=\"onPickerChange()\"\n                                [showWeeks]=\"showWeeks\"\n                                [datepickerMode]=\"datepickerMode\"\n                                [minDate]=\"minDate\"\n                                [maxDate]=\"maxDate\"\n                                [dateDisabled]=\"dateDisabled\"></datepicker>\n                    <timepicker *ngIf=\"showTime\" \n                                [(ngModel)]=\"localValue\" \n                                (ngModelChange)=\"onPickerChange()\"></timepicker>\n                </li>\n                <li class=\"mx-2 mb-2\">\n                    <span class=\"btn-group pull-left\">\n                        <button type=\"button\" (click)=\"onNow()\" \n                                *ngIf=\"nowButton.show\" \n                                [ngClass]=\"nowButton.cssClass\">{{ nowButton.label }}</button>\n                        <button type=\"button\" (click)=\"onClear()\" \n                                *ngIf=\"clearButton.show\" \n                                [ngClass]=\"clearButton.cssClass\">{{ clearButton.label }}</button>\n                    </span>\n                    <span class=\"btn-group pull-right\">\n                        <button type=\"button\" (click)=\"offClick()\" \n                                *ngIf=\"closeButton.show\" \n                                [ngClass]=\"closeButton.cssClass\">{{ closeButton.label }}</button>\n                    </span>\n                </li>\n            </ul>\n        </div>\n    "
                },] },
    ];
    /**
     * @nocollapse
     */
    DatetimePopupComponent.ctorParameters = function () { return []; };
    DatetimePopupComponent.propDecorators = {
        'value': [{ type: core.Input },],
        'valueChange': [{ type: core.Output },],
        'showPopup': [{ type: core.Input },],
        'showPopupChange': [{ type: core.Output },],
        'showDate': [{ type: core.Input },],
        'showTime': [{ type: core.Input },],
        'showWeeks': [{ type: core.Input },],
        'datepickerMode': [{ type: core.Input },],
        'initDate': [{ type: core.Input },],
        'minDate': [{ type: core.Input },],
        'maxDate': [{ type: core.Input },],
        'dateDisabled': [{ type: core.Input },],
        'nowButton': [{ type: core.Input },],
        'clearButton': [{ type: core.Input },],
        'closeButton': [{ type: core.Input },],
    };
    return DatetimePopupComponent;
}());

var OffClickDirective = /** @class */ (function () {
    /**
     * @param {?} elementRef
     */
    function OffClickDirective(elementRef) {
        this.elementRef = elementRef;
        this.offClick = new core.EventEmitter();
    }
    /**
     * @return {?}
     */
    OffClickDirective.prototype.ngOnInit = function () {
        var _this = this;
        this.eventHandler = function ($event) {
            $event.stopPropagation();
            if (!_this.elementRef.nativeElement.contains($event.target)) {
                _this.offClick.emit(null);
            }
        };
        document.addEventListener('mouseup', this.eventHandler);
    };
    /**
     * @return {?}
     */
    OffClickDirective.prototype.ngOnDestroy = function () {
        document.removeEventListener('mouseup', this.eventHandler);
    };
    OffClickDirective.decorators = [
        { type: core.Directive, args: [{
                    selector: '[offClick]'
                },] },
    ];
    /**
     * @nocollapse
     */
    OffClickDirective.ctorParameters = function () { return [
        { type: core.ElementRef, },
    ]; };
    OffClickDirective.propDecorators = {
        'offClick': [{ type: core.Output },],
    };
    return OffClickDirective;
}());

var DatetimePopupModule = /** @class */ (function () {
    function DatetimePopupModule() {
    }
    /**
     * @return {?}
     */
    DatetimePopupModule.forRoot = function () {
        return {
            ngModule: DatetimePopupModule,
            providers: [
                datepicker.DatepickerConfig,
                timepicker.TimepickerConfig
            ]
        };
    };
    DatetimePopupModule.decorators = [
        { type: core.NgModule, args: [{
                    imports: [
                        common.CommonModule,
                        forms.FormsModule,
                        datepicker.DatepickerModule.forRoot(),
                        timepicker.TimepickerModule.forRoot()
                    ],
                    declarations: [
                        DatetimePopupComponent,
                        OffClickDirective
                    ],
                    exports: [
                        DatetimePopupComponent
                    ],
                    entryComponents: [
                        DatetimePopupComponent
                    ]
                },] },
    ];
    /**
     * @nocollapse
     */
    DatetimePopupModule.ctorParameters = function () { return []; };
    return DatetimePopupModule;
}());

exports.DatetimePopupModule = DatetimePopupModule;

Object.defineProperty(exports, '__esModule', { value: true });

})));
